@@ -173,11 +173,13 @@ xnee_replay_event_handler_sleep_amt(xnee_data* xd,
   
   /*
     printf ("xnee_calc_sleep_amount : %lu : (%lu) : %lu :  %lu ===>  %d\n",     
-   	  last_diff, first_diff,  
-   	  record_last_diff, record_first_diff, 
-   	  sleep_amt);    
-  */  
-  
+	    last_diff, 
+	    first_diff,  
+	    record_last_diff, 
+	    record_first_diff, 
+	    sleep_amt);
+    fflush(stdout);
+  */
   
 
   return sleep_amt;
@@ -215,6 +217,8 @@ xnee_replay_event_handler( xnee_data* xd,
 		KeyPress, 
 		KeyRelease));
   
+
+#ifdef XNEE_XINPUT_SUPPORT
   if ( xnee_is_forced_core_device_events(xd))
    {
       if ( xindata->type == XNEE_PROTO_XINPUT_EVENT_SLAVE )
@@ -223,6 +227,7 @@ xnee_replay_event_handler( xnee_data* xd,
 	}
       else
 	{
+#endif /* XNEE_XINPUT_SUPPORT*/
 	  /* If we use the last args to the XTestFakexxx functions
 	   * it is harder to synchronize .... 
 	   * XNEE_FAKE_SLEEP is a macro for usleep 
@@ -267,14 +272,13 @@ xnee_replay_event_handler( xnee_data* xd,
 	      x      = (int) xindata->u.event.x ; 
 	      y      = (int) xindata->u.event.y ; 
 
-	      if ( (screen >= 0 ) && (screen < 1000))
+	      if (xnee_is_screen_ok(xd, screen))
 		{
 		  /* xnee_set_verbose(xd); */
 		  sleep_amt = xnee_replay_event_handler_sleep_amt(xd, 
 								  xindata, 
 								  last_elapsed,
 								  0);
-		  
 		  /*xnee_unset_verbose(xd); */
 		  xnee_fake_motion_event (xd,
 					  screen,
@@ -298,6 +302,7 @@ xnee_replay_event_handler( xnee_data* xd,
 	      return_value= XNEE_NOT_REPLAYABLE;
 	      break;
 	    }
+#ifdef XNEE_XINPUT_SUPPORT
 	}
     }
   else
@@ -355,6 +360,7 @@ xnee_replay_event_handler( xnee_data* xd,
 	  ;
 	}
     }
+#endif /* XNEE_XINPUT_SUPPORT*/
   
   if (return_value==0)
     {
@@ -382,8 +388,12 @@ int
 xnee_fake_key_event_impl  (xnee_data* xd, int keycode, Bool bo, int dtime, int deviceid)
 {
   int i=0;
+
   int size= xd->distr_list_size;
 
+#ifdef XNEE_XINPUT_SUPPORT
+	  XDevice *xdevice;
+#endif /* XNEE_XINPUT_SUPPORT*/
 
   if (!xnee_is_recorder (xd))
     {
@@ -394,12 +404,10 @@ xnee_fake_key_event_impl  (xnee_data* xd, int keycode, Bool bo, int dtime, int d
 	}
       else if (deviceid != 0 )
 	{
-	  XDevice *xdevice;
+#ifdef XNEE_XINPUT_SUPPORT
 	 
-	  xnee_set_verbose(xd);
 	  xdevice = xnee_get_xinput_device(xd, deviceid);
 
-	  xnee_unset_verbose(xd);
 	  xnee_fake_sleep (dtime); 
 	  
 
@@ -411,9 +419,12 @@ xnee_fake_key_event_impl  (xnee_data* xd, int keycode, Bool bo, int dtime, int d
 				  0,
 				  1);
 
+#endif /* XNEE_XINPUT_SUPPORT*/
 	}
       else
 	{
+	  printf ("fake key %d   in %d\n",
+		  keycode, dtime);
 	  xnee_fake_sleep (dtime);
 	  xnee_verbose((xd, "XTestFakeKeyEvent (%d, %d, %d, %d ))\n",
 			(int) xd->fake, 
@@ -432,8 +443,8 @@ xnee_fake_key_event_impl  (xnee_data* xd, int keycode, Bool bo, int dtime, int d
 			    (int) bo, 
 			    (int) dtime));
 	      XTestFakeKeyEvent (xd->distr_list[i].dpy, keycode, bo, dtime);
+	      XFlush (xd->distr_list[i].dpy);
 	    }
-	  XFlush (xd->distr_list[i].dpy);
 	}
     }
   xnee_verbose((xd,"\n\n\n"));
@@ -522,6 +533,10 @@ xnee_fake_button_event_impl (xnee_data* xd,
   int i=0;
   int size= xd->distr_list_size;
   
+#ifdef XNEE_XINPUT_SUPPORT
+	  XDevice *xdevice;
+#endif /* XNEE_XINPUT_SUPPORT*/
+
   if (!xnee_is_recorder (xd))
     {
       if (xnee_is_swinput_playback(xd))
@@ -531,6 +546,7 @@ xnee_fake_button_event_impl (xnee_data* xd,
 	}
       else if (deviceid != 0 )
 	{
+#ifdef XNEE_XINPUT_SUPPORT
 	  XDevice *xdevice;
 	 
 	  xdevice = xnee_get_xinput_device(xd, deviceid);
@@ -543,6 +559,7 @@ xnee_fake_button_event_impl (xnee_data* xd,
 				     xnee_xi_last_know_pointer_pos,
 				     2,
 				     1);
+#endif /* XNEE_XINPUT_SUPPORT*/
 	}
       else
 	{
@@ -593,6 +610,10 @@ xnee_fake_motion_event_impl (xnee_data* xd,
   int size= xd->distr_list_size;
   int new_x;
   int new_y;
+#ifdef XNEE_XINPUT_SUPPORT
+  int axes[2];
+  XDevice *xdevice;
+#endif /* XNEE_XINPUT_SUPPORT*/
 
   xnee_verbose((xd, "---> xnee_fake_motion_event\n"));
   xnee_verbose((xd, "---  delay = %d\n", (int)dtime));
@@ -626,11 +647,9 @@ xnee_fake_motion_event_impl (xnee_data* xd,
 	}
       else
 	{
-	  int axes[2];
+#ifdef XNEE_XINPUT_SUPPORT
 	  axes[0] = new_x;
 	  axes[1] = new_y;
-	  XDevice *xdevice;
-	  
 	  xnee_verbose((xd, "---  xi find device\n"));
 	 
 	  xdevice = xnee_get_xinput_device(xd, deviceid);
@@ -664,6 +683,7 @@ xnee_fake_motion_event_impl (xnee_data* xd,
 				     axes,
 				     2,
 				     1);
+#endif /* XNEE_XINPUT_SUPPORT*/
 	}
       
       for (i=0; i<size ; i++)
